@@ -24,8 +24,6 @@ class PhiWsData(BaseModel):
     # The root directory for the workspace.
     # This field indicates that this ws has been downloaded on this machine
     ws_dir_path: Optional[Path] = None
-    # WorkspaceConfig for the workspace
-    ws_config: Optional[WorkspaceConfig] = None
     # Path for the WorkspaceConfig file
     ws_config_file_path: Optional[Path] = None
     # A Set of WorkspaceSetupActions which this workspace must satisfy to become valid.
@@ -43,6 +41,8 @@ class PhiWsData(BaseModel):
     # Timestamp when this ws was last updated
     last_update_ts: Optional[datetime.datetime] = None
 
+    cached_ws_config: Optional[WorkspaceConfig] = None
+
     class Config:
         arbitrary_types_allowed = True
 
@@ -50,7 +50,14 @@ class PhiWsData(BaseModel):
     ## WorkspaceConfig functions
     ######################################################
 
-    def load_workspace_from_config_file(self) -> None:
+    @property
+    def ws_config(self) -> Optional[WorkspaceConfig]:
+        """
+        Returns the WorkspaceConfig for this workspace
+        """
+
+        if self.cached_ws_config is not None:
+            return self.cached_ws_config
 
         if self.ws_config_file_path is None or self.ws_dir_path is None:
             raise WorkspaceConfigException("WorkspaceConfig invalid")
@@ -65,7 +72,6 @@ class PhiWsData(BaseModel):
 
         if is_empty(ws_configs):
             logger.debug(f"No WorkspaceConfig found")
-            self.ws_config = None
             raise WorkspaceConfigException("No WorkspaceConfig found")
 
         if len(ws_configs) > 1:
@@ -74,9 +80,9 @@ class PhiWsData(BaseModel):
                     len(ws_configs)
                 )
             )
-        ws_config: WorkspaceConfig = ws_configs[0]
-        # logger.debug("loading workspace config:\n{}".format(ws_config.args))
-        self.ws_config = ws_config
+        self.cached_ws_config = ws_configs[0]
+        # logger.debug("WorkspaceConfig:\n{}".format(self.cached_ws_config.args))
+        return self.cached_ws_config
 
     ######################################################
     ## Print functions
