@@ -16,7 +16,9 @@ def add_ws_dir_to_path(ws_dir_path: Path) -> None:
         logger.debug(f"Adding {ws_dir_path} to path")
         sys.path.insert(0, str(ws_dir_path))
     except Exception as e:
-        logger.warning(f"Could not add {ws_dir_path} to Path. This will break workspace imports")
+        logger.warning(
+            f"Could not add {ws_dir_path} to Path. This will break workspace imports"
+        )
         logger.exception(e)
 
 
